<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Admin\Service;

use Admin\Entity\CurrencyContent;
use Doctrine\ORM\EntityManager;

class CurrencyContentManager
{
    private $entityManager;

    public function __construct(
        EntityManager $entityManager
    )
    {
        $this->entityManager = $entityManager;
    }

    /**
     * 添加货币内容
     * @param array $data
     * @param $currencyId
     * @return void
     * @throws \Doctrine\ORM\ORMException
     * @throws \Doctrine\ORM\OptimisticLockException
     */
    public function addCurrencyContent(array $data, $currencyId)
    {
        foreach (SHOP_LANGUAGE as $language) {
            $currencyName = $data['currencyName' . $language];
            $currencyContent = new CurrencyContent();
            $currencyContent->setLanguageCode($language);
            $currencyContent->setCurrencyId($currencyId);
            $currencyContent->setCurrencyName($currencyName);

            $this->entityManager->persist($currencyContent);
            $this->entityManager->flush();
        }
    }

    /**
     * 编辑货币内容
     * @param array $data
     * @param $currencyId
     * @return void
     * @throws \Doctrine\ORM\ORMException
     * @throws \Doctrine\ORM\OptimisticLockException
     */
    public function editCurrencyContent(array $data, $currencyId)
    {
        foreach (SHOP_LANGUAGE as $language) {
            $currencyName = $data['currencyName' . $language];
            $currencyContent = $this->entityManager->getRepository(CurrencyContent::class)->findOneBy(['currencyId' => $currencyId, 'languageCode' => $language]);
            if ($currencyContent) {
                $currencyContent->setCurrencyName($currencyName);
            } else {
                $currencyContent = new CurrencyContent();
                $currencyContent->setLanguageCode($language);
                $currencyContent->setCurrencyId($currencyId);
                $currencyContent->setCurrencyName($currencyName);
                $this->entityManager->persist($currencyContent);
            }
            $this->entityManager->flush();
        }
    }

    /**
     * 删除货币内容
     * @param $currencyId
     * @return void
     */
    public function deleteCurrencyContent($currencyId)
    {
        $qb = $this->entityManager->createQueryBuilder();
        $qb->delete(CurrencyContent::class, 'c')->where($qb->expr()->eq('c.currencyId', $currencyId));
        $qb->getQuery()->execute();
    }
}