<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Goods\Service;

use Doctrine\ORM\EntityManager;
use Goods\Entity\GoodsAttributeContent;

class GoodsAttributeContentManager
{
    private $entityManager;

    public function __construct(
        EntityManager $entityManager
    )
    {
        $this->entityManager = $entityManager;
    }

    /**
     * 添加或编辑属性名称内容
     * @param array $data
     * @param $attributeId
     * @return void
     * @throws \Doctrine\ORM\ORMException
     * @throws \Doctrine\ORM\OptimisticLockException
     */
    public function addOrEditAttributeContent(array $data, $attributeId)
    {
        foreach (SHOP_LANGUAGE as $language) {
            $attributeContent = $this->entityManager->getRepository(GoodsAttributeContent::class)->findOneBy(['attributeId' => $attributeId, 'languageCode' => $language]);
            if ($attributeContent) {
                $attributeContent->setAttributeName($data['attributeName'.$language]);
            } else {
                $attributeContent = new GoodsAttributeContent();
                $attributeContent->setAttributeId($attributeId);
                $attributeContent->setLanguageCode($language);
                $attributeContent->setAttributeName($data['attributeName'.$language]);

                $this->entityManager->persist($attributeContent);
            }
            $this->entityManager->flush();
        }
    }

    /**
     * 删除属性名称内容
     * @param $attributeId
     * @return void
     */
    public function deleteAttributeContent($attributeId)
    {
        $qb = $this->entityManager->createQueryBuilder();
        $qb->delete(GoodsAttributeContent::class, 'c')->where($qb->expr()->eq('c.attributeId', $attributeId));
        $qb->getQuery()->execute();
    }
}