<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Goods\Service;

use Admin\Data\Common;
use Admin\Data\Config;
use Doctrine\ORM\EntityManager;
use Goods\Entity\GoodsCommonContentExt;

class GoodsCommonContentExtManager
{
    private $entityManager;

    public function __construct(
        EntityManager $entityManager
    )
    {
        $this->entityManager = $entityManager;
    }

    /**
     * 编辑商品公共内容扩展
     * @param array $data
     * @param $contentId
     * @return void
     * @throws \Doctrine\ORM\ORMException
     * @throws \Doctrine\ORM\OptimisticLockException
     */
    public function addOrEditCommonContentExt(array $data, $contentId)
    {
        foreach (SHOP_LANGUAGE as $language) {
            $contentExt = $this->entityManager->getRepository(GoodsCommonContentExt::class)->findOneBy(['contentId' => $contentId, 'languageCode' => $language]);
            if ($contentExt) {
                $contentExt->setContentBody($data['contentBody'.$language]);
            } else {
                $contentExt = new GoodsCommonContentExt();
                $contentExt->setContentId($contentId);
                $contentExt->setLanguageCode($language);
                $contentExt->setContentBody($data['contentBody'.$language]);

                $this->entityManager->persist($contentExt);
            }
            $this->entityManager->flush();
        }
    }

    /**
     * 删除商品公共内容扩展
     * @param $contentId
     * @return array|null
     * @throws \Doctrine\ORM\ORMException
     * @throws \Doctrine\ORM\OptimisticLockException
     */
    public function deleteCommonContentExt($contentId)
    {
        $contentExtList = $this->entityManager->getRepository(GoodsCommonContentExt::class)->findBy(['contentId' => $contentId]);
        $body = '';
        foreach ($contentExtList as $value) {
            $body .= $value->getContentBody();

            $this->entityManager->remove($value);
            $this->entityManager->flush();
        }

        $imageList = Common::bodyImageArray($body);

        if ($imageList) foreach ($imageList as $imageValue) {
            if (stripos($imageValue, 'http') !== false) continue;
            @unlink(Config::GOODS_COMMON_IMAGE_PATH . basename($imageValue));
        }

        return $imageList;
    }
}