<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Operation\Service;

use Doctrine\ORM\EntityManager;
use Operation\Entity\AdContent;

class AdContentManager
{
    private $entityManager;

    public function __construct(
        EntityManager $entityManager
    )
    {
        $this->entityManager = $entityManager;
    }

    /**
     * 添加或者编辑广告内容
     * @param array $data
     * @param $adId
     * @return void
     * @throws \Doctrine\ORM\ORMException
     * @throws \Doctrine\ORM\OptimisticLockException
     */
    public function addOrEditAdContent(array $data, $adId)
    {
        foreach (SHOP_LANGUAGE as $language) {
            $adContent = $this->entityManager->getRepository(AdContent::class)->findOneBy(['adId' => $adId, 'languageCode' => $language]);
            if ($adContent) {
                if (isset($data['adWords'.$language])) $adContent->setAdWords($data['adWords'.$language]);
            } else {
                $adContent = new AdContent();
                $adContent->setLanguageCode($language);
                $adContent->setAdId($adId);
                if (isset($data['adWords'.$language])) $adContent->setAdWords($data['adWords'.$language]);

                $this->entityManager->persist($adContent);
            }
            $this->entityManager->flush();
        }
    }

    /**
     * 删除广告内容
     * @param $adId
     * @return void
     */
    public function deleteAdContent($adId)
    {
        $qb = $this->entityManager->createQueryBuilder();
        $qb->delete(AdContent::class, 'c')->where($qb->expr()->eq('c.adId', $adId));
        $qb->getQuery()->execute();
    }
}