<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Operation\Service;

use Doctrine\ORM\EntityManager;
use Operation\Entity\DiscountRuleContent;

class DiscountRuleContentManager
{
    private $entityManager;

    public function __construct(
        EntityManager $entityManager
    )
    {
        $this->entityManager = $entityManager;
    }

    /**
     * 添加和编辑规则内容
     * @param array $data
     * @param $discountRuleId
     * @return void|null
     * @throws \Doctrine\ORM\ORMException
     * @throws \Doctrine\ORM\OptimisticLockException
     */
    function addOrEditDiscountRuleContent(array $data, $discountRuleId)
    {
        foreach (SHOP_LANGUAGE as $language) {
            $ruleContent = $this->entityManager->getRepository(DiscountRuleContent::class)->findOneBy(['discountRuleId' => $discountRuleId, 'languageCode' => $language]);
            if ($ruleContent) {
                $ruleContent->setDiscountRuleTitle($data['discountRuleTitle'.$language]);
                $ruleContent->setDiscountRuleInfo($data['discountRuleInfo'.$language]);
            } else {
                $ruleContent = new DiscountRuleContent();
                $ruleContent->setLanguageCode($language);
                $ruleContent->setDiscountRuleId($discountRuleId);
                $ruleContent->setDiscountRuleTitle($data['discountRuleTitle'.$language]);
                $ruleContent->setDiscountRuleInfo($data['discountRuleInfo'.$language]);

                $this->entityManager->persist($ruleContent);
            }
            $this->entityManager->flush();
        }
    }

    /**
     * 删除规则内容
     * @param $discountRuleId
     * @return void
     */
    function deleteDiscountRuleContent($discountRuleId)
    {
        $qb = $this->entityManager->createQueryBuilder();
        $qb->delete(DiscountRuleContent::class, 'c')->where($qb->expr()->eq('c.discountRuleId', $discountRuleId));
        $qb->getQuery()->execute();
    }
}